/*
**    y = cdfbvt(mu1,mu2,s1,s2,rho,nu);
**
** integral of the bivariate t distribution from -infinity to zero
** over both dimensions.
**
** by Gary King <King@Harvard.Edu>, http://GKing.Harvard.Edu
**
** INPUTS:
** mu1,mu2 = means
** s1,s2 = scatter "standard deviations"
** rho   = correlation
** nu    = degrees of freedom
** (all parameters must be scalars or equally sized vectors; or mu1 and m1
** can be equally sized vectors and the rest can be scalar)
**
** OUTPUT
** y = prob(x<0,y<0|mu1,mu2,s1,s2,rho,nu)
*/
proc cdfbvt(mu1,mu2,s1,s2,rho,nu);
  local res,tst,limits,o;
  clearg _cdfbvt_params,_intord;
  if rows(s1)==1;
    o=ones(rows(mu1),1);
    s1=s1.*o;
    s2=s2.*o;
    rho=rho.*o;
    nu=nu.*o;
  endif;
  _cdfbvt_params=mu1~mu2~s1~s2~rho~nu;
  _intord=40;

  limits={0, -10};   /* might need to change -99 for some applications */
  res = intquad1(&_cdfbvt_proc,limits);

/*tst=(res.<1e-270);
  res=recode(res,tst~(res.>1),1e-270|1);*/

  retp(res);
endp;

/*
**  dens = _cdfbvt_proc(y);
**
** support proc for cdfbvt(), written so that only one integral is
** necessary to get double integral
**
** dens = value of the density to be integrated given a specified
**        value y for the 2nd variable
**
*/
proc _cdfbvt_proc(y);
  local mu1,mu2,s1,s2,rho,nu,mu,var,res,t1,t2,t3,t4;
  mu1=_cdfbvt_params[.,1];
  mu2=_cdfbvt_params[.,2];
  s1=_cdfbvt_params[.,3];
  s2=_cdfbvt_params[.,4];
  rho=_cdfbvt_params[.,5];
  nu=_cdfbvt_params[.,6];

  /* conditional mean and variance */
  mu=mu1+(rho.*s1./s2).*(y-mu2);
  var=(s1^2).*(1-(rho^2)).*((nu+(((y-mu2)^2)./(s2^2)))./(nu+1));

  /* T(x,y)=T(y)T(x|y) integrated over x from -infty to 0*/
  res=pdft2(y,mu2,s2,nu).*cdft2(0,mu,sqrt(var),nu+1);

  retp(res);
endp;
